@@ -170,7 +170,7 @@ class MaoboApp(QApplication):
         self.doReloadBackgroundIcon()
           
     def lastWindowClosed(self):
-        print "lastWindowClosed"        
+        print "lastWindowClosed"
         '''TODO: need to check the updaters state, and terminate them'''
 
           
@@ -522,8 +522,9 @@ class MaoboApp(QApplication):
         settingAction=self.create_action(unicode("微博设置"), self.show_setting_form)
         delcacheAction=self.create_action(unicode("清理缓存"), self.delete_cache)
         aboutAction=self.create_action(unicode("关于软件"), self.show_about_form)
+        exitAction=self.create_action(unicode("完全退出"), self.maebo_exit)
         self.menuBar=QMenuBar()
-        self.add_actions(self.menuBar, (accountsManaAction,settingAction,delcacheAction,aboutAction))
+        self.add_actions(self.menuBar, (accountsManaAction,settingAction,delcacheAction,aboutAction,exitAction))
         self.defaultWin.setMenuBar(self.menuBar)
 
     def create_accounts_window(self):
@@ -536,21 +537,31 @@ class MaoboApp(QApplication):
         settingAction=self.create_action(unicode("微博设置"), self.show_setting_form)
         delcacheAction=self.create_action(unicode("清理缓存"), self.delete_cache)
         aboutAction=self.create_action(unicode("关于软件"), self.show_about_form)
+        exitAction=self.create_action(unicode("完全退出"), self.maebo_exit)
         self.menuBar=QMenuBar()
-        self.add_actions(self.menuBar, (accountsManaAction,settingAction,delcacheAction,aboutAction))
+        self.add_actions(self.menuBar, (accountsManaAction,settingAction,delcacheAction,aboutAction,exitAction))
         self.accountsWin.setMenuBar(self.menuBar)
 
     def delete_cache(self):
         # delete cache images and data. befor 30 days.
-        
         self.controller.del_status_by_cache()
-        
-        import os
         os.system('find '+Utils.THUMBNAIL_DIR+' -mtime +7 | xargs rm -rf')
         os.system('rm -rf '+Utils.LOG_FILE)
         
         self.show_notice("成功清理一周之前的图片、微博、以及日志数据缓存。")
         
+    def maebo_exit(self):
+        print "exit all."
+        
+        print "hide background icon"
+        try:
+            os.system('sudo rm -f /usr/share/applications/hildon-status-menu/maebo_status_menu.desktop')
+        except:
+            pass
+        
+        os.system('pkill -f "qt_pynotify.py"')
+        os.system('pkill -f "maebo.py"')
+        
     def account_clicked(self,index):
         self.logger.debug("account_clicked")
         row=index.row()
@@ -1399,13 +1410,13 @@ class MaoboApp(QApplication):
         if Utils.settings["background"] == "True":
             print "show background icon"
             try:                    
-                os.system('cp /opt/maebo/maebo_status_menu.desktop /usr/share/applications/hildon-status-menu/')
+                os.system('sudo cp /opt/maebo/maebo_status_menu.desktop /usr/share/applications/hildon-status-menu/')
             except:
                 pass
         else:
             print "hide background icon"
             try:
-                os.system('rm /usr/share/applications/hildon-status-menu/maebo_status_menu.desktop')
+                os.system('sudo rm -f /usr/share/applications/hildon-status-menu/maebo_status_menu.desktop')
             except:
                 pass
     
@@ -1467,7 +1478,7 @@ class MaeboService(dbus.service.Object):
     @dbus.service.method(dbus_interface=SESSION_DBUS_IFACE)
     def show_window(self):
         self.app.accountsWin.activateWindow()   
-        self.app.accountsWin.show()             
+        self.app.accountsWin.show()
 
 def main():    
     if dbus.SessionBus().request_name(SESSION_DBUS_NAME) != dbus.bus.REQUEST_NAME_REPLY_PRIMARY_OWNER:
